@@ -24,7 +24,7 @@ class Diva::Model
   # selfにあってotherにもあるカラムはotherの内容で上書きされる。
   # 上書き後、データはDataSourceに保存される
   def merge(other)
-    @value.update(other.to_hash)
+    @value.update(other.to_h)
     validate
     self.class.store_datum(self)
   end
@@ -80,7 +80,7 @@ class Diva::Model
     self == other
   end
 
-  def to_hash
+  def to_h
     self.class.fields.to_h { |f| [f.name, fetch(f.name)] }
   end
 
@@ -106,15 +106,15 @@ class Diva::Model
     raise "argument is #{@value}, not Hash" unless @value.is_a?(Hash)
     self.class.fields.each do |field|
       @value[field.name] = field.type.cast(@value[field.name])
-    rescue Diva::InvalidTypeError => exception
-      raise Diva::InvalidTypeError, "#{exception} in field `#{field}'"
+    rescue Diva::InvalidTypeError
+      raise Diva::InvalidTypeError, "#{self.class}.#{field} (#{field.type}): Invalid assign #{@value[field.name].inspect}:#{@value[field.name].class}"
     end
   end
 
   # キーとして定義されていない値を全て除外した配列を生成して返す。
   # また、Modelを子に含んでいる場合、それを外部キーに変換する。
   def filtering
-    datum = to_hash
+    datum = to_h
     result = {}
     self.class.fields.each do |field|
       result[field.name] = field.type.cast(datum[field.name])
@@ -146,6 +146,14 @@ class Diva::Model
     end
   end
 
+  def deconstruct_keys(keys)
+    if keys
+      @value.slice(*keys) # 高速化のため、fetchを呼び出していない
+    else
+      @value
+    end
+  end
+
   private
 
   # URIがデフォルトで使うpath要素
